Crate substreams_macro

Crate substreams_macro 

Macros

test_map
Test helper macro that transforms a handler call to use the __impl_ testable function.

Attribute Macros

map
Marks a function as a Substreams map handler, generating the necessary WASM boilerplate.
store
Marks a function as a Substreams store handler, generating the necessary WASM boilerplate.

Derive Macros

StoreWriter